4b31ffef创建于 2020年8月19日历史提交
diff -urN lucene-4.10.4/benchmark/conf/spatial.alg lucene-4.10.4.new/benchmark/conf/spatial.alg
--- lucene-4.10.4/benchmark/conf/spatial.alg	2014-07-23 04:47:15.000000000 +0000
+++ lucene-4.10.4.new/benchmark/conf/spatial.alg	2020-06-09 01:52:52.242846354 +0000
@@ -23,7 +23,7 @@
 ### Spatial Context, Grid, Strategy config
 doc.maker=org.apache.lucene.benchmark.byTask.feeds.SpatialDocMaker
 #  SpatialContext:    see SpatialContextFactory.makeSpatialContext
-#spatial.spatialContextFactory=com.spatial4j.core.context.jts.JtsSpatialContextFactory
+#spatial.spatialContextFactory=org.locationtech.spatial4j.context.jts.JtsSpatialContextFactory
 #spatial.geo=true
 #spatial.distCalculator=haversine
 #spatial.worldBounds=...
diff -urN lucene-4.10.4/benchmark/src/java/org/apache/lucene/benchmark/byTask/feeds/SpatialDocMaker.java lucene-4.10.4.new/benchmark/src/java/org/apache/lucene/benchmark/byTask/feeds/SpatialDocMaker.java
--- lucene-4.10.4/benchmark/src/java/org/apache/lucene/benchmark/byTask/feeds/SpatialDocMaker.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/benchmark/src/java/org/apache/lucene/benchmark/byTask/feeds/SpatialDocMaker.java	2020-06-09 01:52:52.242846354 +0000
@@ -17,10 +17,10 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.context.SpatialContextFactory;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.context.SpatialContextFactory;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.benchmark.byTask.utils.Config;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxOverlapRatioValueSource.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxOverlapRatioValueSource.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxOverlapRatioValueSource.java	2014-07-08 14:15:35.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxOverlapRatioValueSource.java	2020-06-09 01:52:52.242846354 +0000
@@ -16,7 +16,7 @@
  */
 package org.apache.lucene.spatial.bbox;
 
-import com.spatial4j.core.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Rectangle;
 import org.apache.lucene.queries.function.ValueSource;
 import org.apache.lucene.search.Explanation;
 
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxSimilarityValueSource.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxSimilarityValueSource.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxSimilarityValueSource.java	2014-07-08 14:15:35.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxSimilarityValueSource.java	2020-06-09 01:52:52.246846413 +0000
@@ -17,7 +17,7 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Rectangle;
 import org.apache.lucene.index.AtomicReaderContext;
 import org.apache.lucene.queries.function.FunctionValues;
 import org.apache.lucene.queries.function.ValueSource;
@@ -31,7 +31,7 @@
 /**
  * A base class for calculating a spatial relevance rank per document from a provided
  * {@link ValueSource} in which {@link FunctionValues#objectVal(int)} returns a {@link
- * com.spatial4j.core.shape.Rectangle}.
+ * org.locationtech.spatial4j.shape.Rectangle}.
  * <p/>
  * Implementers: remember to implement equals & hashCode if you have
  * fields!
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxStrategy.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxStrategy.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxStrategy.java	2014-08-13 09:36:54.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxStrategy.java	2020-06-09 01:52:52.242846354 +0000
@@ -17,10 +17,10 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Rectangle;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Shape;
 
 import org.apache.lucene.document.DoubleField;
 import org.apache.lucene.document.Field;
@@ -68,7 +68,7 @@
  * and a boolean to mark a dateline cross. Depending on the particular {@link
  * SpatialOperation}s, there are a variety of {@link NumericRangeQuery}s to be
  * done.
- * The {@link #makeOverlapRatioValueSource(com.spatial4j.core.shape.Rectangle, double)}
+ * The {@link #makeOverlapRatioValueSource(org.locationtech.spatial4j.shape.Rectangle, double)}
  * works by calculating the query bbox overlap percentage against the indexed
  * shape overlap percentage. The indexed shape's coordinates are retrieved from
  * {@link AtomicReader#getNumericDocValues}.
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxValueSource.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxValueSource.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxValueSource.java	2014-07-08 14:15:35.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/bbox/BBoxValueSource.java	2020-06-09 01:52:52.246846413 +0000
@@ -17,7 +17,7 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Rectangle;
 import org.apache.lucene.index.AtomicReader;
 import org.apache.lucene.index.AtomicReaderContext;
 import org.apache.lucene.index.DocValues;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/AbstractPrefixTreeFilter.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/AbstractPrefixTreeFilter.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/AbstractPrefixTreeFilter.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/AbstractPrefixTreeFilter.java	2020-06-09 01:52:52.254846531 +0000
@@ -17,7 +17,7 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.index.AtomicReader;
 import org.apache.lucene.index.AtomicReaderContext;
 import org.apache.lucene.index.DocsEnum;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/AbstractVisitingPrefixTreeFilter.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/AbstractVisitingPrefixTreeFilter.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/AbstractVisitingPrefixTreeFilter.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/AbstractVisitingPrefixTreeFilter.java	2020-06-09 01:52:52.250846472 +0000
@@ -17,7 +17,7 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.index.AtomicReaderContext;
 import org.apache.lucene.index.TermsEnum;
 import org.apache.lucene.search.DocIdSet;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/ContainsPrefixTreeFilter.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/ContainsPrefixTreeFilter.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/ContainsPrefixTreeFilter.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/ContainsPrefixTreeFilter.java	2020-06-09 01:52:52.254846531 +0000
@@ -17,8 +17,8 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Shape;
-import com.spatial4j.core.shape.SpatialRelation;
+import org.locationtech.spatial4j.shape.Shape;
+import org.locationtech.spatial4j.shape.SpatialRelation;
 
 import org.apache.lucene.index.AtomicReaderContext;
 import org.apache.lucene.index.DocsEnum;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/IntersectsPrefixTreeFilter.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/IntersectsPrefixTreeFilter.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/IntersectsPrefixTreeFilter.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/IntersectsPrefixTreeFilter.java	2020-06-09 01:52:52.254846531 +0000
@@ -17,8 +17,8 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Shape;
-import com.spatial4j.core.shape.SpatialRelation;
+import org.locationtech.spatial4j.shape.Shape;
+import org.locationtech.spatial4j.shape.SpatialRelation;
 import org.apache.lucene.index.AtomicReaderContext;
 import org.apache.lucene.search.DocIdSet;
 import org.apache.lucene.spatial.prefix.tree.Cell;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/PointPrefixTreeFieldCacheProvider.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/PointPrefixTreeFieldCacheProvider.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/PointPrefixTreeFieldCacheProvider.java	2014-04-18 02:07:04.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/PointPrefixTreeFieldCacheProvider.java	2020-06-09 01:52:52.246846413 +0000
@@ -17,7 +17,7 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Point;
+import org.locationtech.spatial4j.shape.Point;
 import org.apache.lucene.spatial.prefix.tree.Cell;
 import org.apache.lucene.spatial.prefix.tree.SpatialPrefixTree;
 import org.apache.lucene.spatial.util.ShapeFieldCacheProvider;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/PrefixTreeStrategy.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/PrefixTreeStrategy.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/PrefixTreeStrategy.java	2014-04-18 02:07:04.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/PrefixTreeStrategy.java	2020-06-09 01:52:52.246846413 +0000
@@ -17,8 +17,8 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.analysis.TokenStream;
 import org.apache.lucene.analysis.tokenattributes.CharTermAttribute;
 import org.apache.lucene.document.Field;
@@ -48,7 +48,7 @@
  * <li>Can index any shape; however only {@link RecursivePrefixTreeStrategy}
  * can effectively search non-point shapes.</li>
  * <li>Can index a variable number of shapes per field value. This strategy
- * can do it via multiple calls to {@link #createIndexableFields(com.spatial4j.core.shape.Shape)}
+ * can do it via multiple calls to {@link #createIndexableFields(org.locationtech.spatial4j.shape.Shape)}
  * for a document or by giving it some sort of Shape aggregate (e.g. JTS
  * WKT MultiPoint).  The shape's boundary is approximated to a grid precision.
  * </li>
@@ -57,7 +57,7 @@
  * <li>Only {@link org.apache.lucene.spatial.query.SpatialOperation#Intersects}
  * is supported.  If only points are indexed then this is effectively equivalent
  * to IsWithin.</li>
- * <li>The strategy supports {@link #makeDistanceValueSource(com.spatial4j.core.shape.Point,double)}
+ * <li>The strategy supports {@link #makeDistanceValueSource(org.locationtech.spatial4j.shape.Point,double)}
  * even for multi-valued data, so long as the indexed data is all points; the
  * behavior is undefined otherwise.  However, <em>it will likely be removed in
  * the future</em> in lieu of using another strategy with a more scalable
@@ -90,7 +90,7 @@
   }
 
   /**
-   * A memory hint used by {@link #makeDistanceValueSource(com.spatial4j.core.shape.Point)}
+   * A memory hint used by {@link #makeDistanceValueSource(org.locationtech.spatial4j.shape.Point)}
    * for how big the initial size of each Document's array should be. The
    * default is 2.  Set this to slightly more than the default expected number
    * of points per document.
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/RecursivePrefixTreeStrategy.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/RecursivePrefixTreeStrategy.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/RecursivePrefixTreeStrategy.java	2014-07-07 15:42:29.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/RecursivePrefixTreeStrategy.java	2020-06-09 01:52:52.254846531 +0000
@@ -17,7 +17,7 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.search.Filter;
 import org.apache.lucene.spatial.DisjointSpatialFilter;
 import org.apache.lucene.spatial.prefix.tree.SpatialPrefixTree;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/tree/GeohashPrefixTree.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/tree/GeohashPrefixTree.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/tree/GeohashPrefixTree.java	2014-04-18 02:07:04.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/tree/GeohashPrefixTree.java	2020-06-09 01:52:52.250846472 +0000
@@ -17,11 +17,11 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.io.GeohashUtils;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Rectangle;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.io.GeohashUtils;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Shape;
 
 import java.util.ArrayList;
 import java.util.Collection;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/tree/QuadPrefixTree.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/tree/QuadPrefixTree.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/tree/QuadPrefixTree.java	2014-04-18 02:07:04.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/tree/QuadPrefixTree.java	2020-06-09 01:52:52.250846472 +0000
@@ -17,11 +17,11 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Rectangle;
-import com.spatial4j.core.shape.Shape;
-import com.spatial4j.core.shape.SpatialRelation;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Shape;
+import org.locationtech.spatial4j.shape.SpatialRelation;
 
 import java.io.PrintStream;
 import java.text.NumberFormat;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/tree/SpatialPrefixTreeFactory.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/tree/SpatialPrefixTreeFactory.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/tree/SpatialPrefixTreeFactory.java	2012-09-22 18:32:49.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/tree/SpatialPrefixTreeFactory.java	2020-06-09 01:52:52.250846472 +0000
@@ -17,8 +17,8 @@
 
 package org.apache.lucene.spatial.prefix.tree;
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.distance.DistanceUtils;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.distance.DistanceUtils;
 
 import java.util.Map;
 
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/query/SpatialArgs.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/query/SpatialArgs.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/query/SpatialArgs.java	2014-07-08 20:18:47.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/query/SpatialArgs.java	2020-06-09 01:52:52.258846589 +0000
@@ -17,10 +17,10 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Rectangle;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Shape;
 
 /**
  * Principally holds the query {@link Shape} and the {@link SpatialOperation}.
@@ -121,8 +121,8 @@
    * inflates the size of the shape but should not shrink it.
    *
    * @return 0 to 0.5
-   * @see #calcDistanceFromErrPct(com.spatial4j.core.shape.Shape, double,
-   *      com.spatial4j.core.context.SpatialContext)
+   * @see #calcDistanceFromErrPct(org.locationtech.spatial4j.shape.Shape, double,
+   *      org.locationtech.spatial4j.context.SpatialContext)
    */
   public Double getDistErrPct() {
     return distErrPct;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/util/ShapeAreaValueSource.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/util/ShapeAreaValueSource.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/util/ShapeAreaValueSource.java	2015-02-26 19:34:12.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/util/ShapeAreaValueSource.java	2020-06-09 01:52:52.258846589 +0000
@@ -17,8 +17,8 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.index.AtomicReaderContext;
 import org.apache.lucene.queries.function.FunctionValues;
 import org.apache.lucene.queries.function.ValueSource;
@@ -33,7 +33,7 @@
  * The area of a Shape retrieved from a ValueSource via
  * {@link org.apache.lucene.queries.function.FunctionValues#objectVal(int)}.
  *
- * @see Shape#getArea(com.spatial4j.core.context.SpatialContext)
+ * @see Shape#getArea(org.locationtech.spatial4j.context.SpatialContext)
  *
  * @lucene.experimental
  */
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/util/ShapeFieldCacheDistanceValueSource.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/util/ShapeFieldCacheDistanceValueSource.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/util/ShapeFieldCacheDistanceValueSource.java	2013-07-24 17:25:11.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/util/ShapeFieldCacheDistanceValueSource.java	2020-06-09 01:52:52.262846648 +0000
@@ -17,9 +17,9 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.distance.DistanceCalculator;
-import com.spatial4j.core.shape.Point;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.distance.DistanceCalculator;
+import org.locationtech.spatial4j.shape.Point;
 import org.apache.lucene.index.AtomicReaderContext;
 import org.apache.lucene.queries.function.FunctionValues;
 import org.apache.lucene.queries.function.ValueSource;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/util/ShapeFieldCache.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/util/ShapeFieldCache.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/util/ShapeFieldCache.java	2014-03-12 18:14:05.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/util/ShapeFieldCache.java	2020-06-09 01:52:52.262846648 +0000
@@ -17,7 +17,7 @@
 
 package org.apache.lucene.spatial.util;
 
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.shape.Shape;
 
 import java.util.ArrayList;
 import java.util.List;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/util/ShapeFieldCacheProvider.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/util/ShapeFieldCacheProvider.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/util/ShapeFieldCacheProvider.java	2014-03-12 18:14:05.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/util/ShapeFieldCacheProvider.java	2020-06-09 01:52:52.262846648 +0000
@@ -17,7 +17,7 @@
 
 package org.apache.lucene.spatial.util;
 
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.index.*;
 import org.apache.lucene.search.DocIdSetIterator;
 import org.apache.lucene.util.BytesRef;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/util/ShapePredicateValueSource.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/util/ShapePredicateValueSource.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/util/ShapePredicateValueSource.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/util/ShapePredicateValueSource.java	2020-06-09 01:52:52.262846648 +0000
@@ -17,7 +17,7 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.index.AtomicReaderContext;
 import org.apache.lucene.queries.function.FunctionValues;
 import org.apache.lucene.queries.function.ValueSource;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/vector/DistanceValueSource.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/vector/DistanceValueSource.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/vector/DistanceValueSource.java	2013-07-24 17:25:11.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/vector/DistanceValueSource.java	2020-06-09 01:52:52.246846413 +0000
@@ -17,8 +17,8 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.distance.DistanceCalculator;
-import com.spatial4j.core.shape.Point;
+import org.locationtech.spatial4j.distance.DistanceCalculator;
+import org.locationtech.spatial4j.shape.Point;
 import org.apache.lucene.index.AtomicReader;
 import org.apache.lucene.index.AtomicReaderContext;
 import org.apache.lucene.queries.function.FunctionValues;
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/vector/PointVectorStrategy.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/vector/PointVectorStrategy.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/vector/PointVectorStrategy.java	2013-07-24 17:25:11.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/vector/PointVectorStrategy.java	2020-06-09 01:52:52.246846413 +0000
@@ -17,11 +17,11 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Circle;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Rectangle;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Circle;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.document.DoubleField;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.document.FieldType;
@@ -55,7 +55,7 @@
  * org.apache.lucene.spatial.query.SpatialOperation#Intersects} and {@link
  * SpatialOperation#IsWithin} is supported.</li>
  * <li>Uses the FieldCache for
- * {@link #makeDistanceValueSource(com.spatial4j.core.shape.Point)} and for
+ * {@link #makeDistanceValueSource(org.locationtech.spatial4j.shape.Point)} and for
  * searching with a Circle.</li>
  * </ul>
  *
@@ -63,7 +63,7 @@
  * This is a simple Strategy.  Search works with {@link NumericRangeQuery}s on
  * an x & y pair of fields.  A Circle query does the same bbox query but adds a
  * ValueSource filter on
- * {@link #makeDistanceValueSource(com.spatial4j.core.shape.Point)}.
+ * {@link #makeDistanceValueSource(org.locationtech.spatial4j.shape.Point)}.
  * <p />
  * One performance shortcoming with this strategy is that a scenario involving
  * both a search using a Circle and sort will result in calculations for the
@@ -109,7 +109,7 @@
     throw new UnsupportedOperationException("Can only index Point, not " + shape);
   }
 
-  /** @see #createIndexableFields(com.spatial4j.core.shape.Shape) */
+  /** @see #createIndexableFields(org.locationtech.spatial4j.shape.Shape) */
   public Field[] createIndexableFields(Point point) {
     FieldType doubleFieldType = new FieldType(DoubleField.TYPE_NOT_STORED);
     doubleFieldType.setNumericPrecisionStep(precisionStep);
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/bbox/TestBBoxStrategy.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/bbox/TestBBoxStrategy.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/bbox/TestBBoxStrategy.java	2014-08-20 17:18:37.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/bbox/TestBBoxStrategy.java	2020-06-09 01:52:52.266846707 +0000
@@ -18,12 +18,12 @@
  */
 
 import com.carrotsearch.randomizedtesting.annotations.Repeat;
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.context.SpatialContextFactory;
-import com.spatial4j.core.distance.DistanceUtils;
-import com.spatial4j.core.shape.Rectangle;
-import com.spatial4j.core.shape.Shape;
-import com.spatial4j.core.shape.impl.RectangleImpl;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.context.SpatialContextFactory;
+import org.locationtech.spatial4j.distance.DistanceUtils;
+import org.locationtech.spatial4j.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Shape;
+import org.locationtech.spatial4j.shape.impl.RectangleImpl;
 import org.apache.lucene.document.FieldType;
 import org.apache.lucene.search.Query;
 import org.apache.lucene.spatial.SpatialMatchConcern;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/DistanceStrategyTest.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/DistanceStrategyTest.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/DistanceStrategyTest.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/DistanceStrategyTest.java	2020-06-09 01:52:52.266846707 +0000
@@ -19,9 +19,9 @@
 
 import com.carrotsearch.randomizedtesting.annotations.Name;
 import com.carrotsearch.randomizedtesting.annotations.ParametersFactory;
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.document.FieldType;
 import org.apache.lucene.spatial.bbox.BBoxStrategy;
 import org.apache.lucene.spatial.prefix.RecursivePrefixTreeStrategy;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/PortedSolr3Test.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/PortedSolr3Test.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/PortedSolr3Test.java	2014-03-12 18:14:05.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/PortedSolr3Test.java	2020-06-09 01:52:52.262846648 +0000
@@ -19,10 +19,10 @@
 
 import com.carrotsearch.randomizedtesting.annotations.Name;
 import com.carrotsearch.randomizedtesting.annotations.ParametersFactory;
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.distance.DistanceUtils;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.distance.DistanceUtils;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.search.FilteredQuery;
 import org.apache.lucene.search.MatchAllDocsQuery;
 import org.apache.lucene.search.Query;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/JtsPolygonTest.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/JtsPolygonTest.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/JtsPolygonTest.java	2014-03-12 18:14:05.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/JtsPolygonTest.java	2020-06-09 01:52:52.270846766 +0000
@@ -17,9 +17,9 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContextFactory;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContextFactory;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.document.Field.Store;
@@ -46,7 +46,7 @@
     try {
       HashMap<String, String> args = new HashMap<>();
       args.put("spatialContextFactory",
-          "com.spatial4j.core.context.jts.JtsSpatialContextFactory");
+          "org.locationtech.spatial4j.context.jts.JtsSpatialContextFactory");
       ctx = SpatialContextFactory.makeSpatialContext(args, getClass().getClassLoader());
     } catch (NoClassDefFoundError e) {
       assumeTrue("This test requires JTS jar: "+e, false);
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/RandomSpatialOpFuzzyPrefixTreeTest.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/RandomSpatialOpFuzzyPrefixTreeTest.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/RandomSpatialOpFuzzyPrefixTreeTest.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/RandomSpatialOpFuzzyPrefixTreeTest.java	2020-06-09 01:52:52.270846766 +0000
@@ -18,14 +18,14 @@
  */
 
 import com.carrotsearch.randomizedtesting.annotations.Repeat;
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.context.SpatialContextFactory;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Rectangle;
-import com.spatial4j.core.shape.Shape;
-import com.spatial4j.core.shape.ShapeCollection;
-import com.spatial4j.core.shape.SpatialRelation;
-import com.spatial4j.core.shape.impl.RectangleImpl;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.context.SpatialContextFactory;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Shape;
+import org.locationtech.spatial4j.shape.ShapeCollection;
+import org.locationtech.spatial4j.shape.SpatialRelation;
+import org.locationtech.spatial4j.shape.impl.RectangleImpl;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.document.StoredField;
@@ -55,10 +55,10 @@
 import static com.carrotsearch.randomizedtesting.RandomizedTest.randomBoolean;
 import static com.carrotsearch.randomizedtesting.RandomizedTest.randomInt;
 import static com.carrotsearch.randomizedtesting.RandomizedTest.randomIntBetween;
-import static com.spatial4j.core.shape.SpatialRelation.CONTAINS;
-import static com.spatial4j.core.shape.SpatialRelation.DISJOINT;
-import static com.spatial4j.core.shape.SpatialRelation.INTERSECTS;
-import static com.spatial4j.core.shape.SpatialRelation.WITHIN;
+import static org.locationtech.spatial4j.shape.SpatialRelation.CONTAINS;
+import static org.locationtech.spatial4j.shape.SpatialRelation.DISJOINT;
+import static org.locationtech.spatial4j.shape.SpatialRelation.INTERSECTS;
+import static org.locationtech.spatial4j.shape.SpatialRelation.WITHIN;
 
 /** Randomized PrefixTree test that considers the fuzziness of the
  * results introduced by grid approximation. */
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/RandomSpatialOpStrategyTestCase.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/RandomSpatialOpStrategyTestCase.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/RandomSpatialOpStrategyTestCase.java	2014-06-19 18:40:11.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/RandomSpatialOpStrategyTestCase.java	2020-06-09 01:52:52.270846766 +0000
@@ -17,7 +17,7 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.search.Query;
 import org.apache.lucene.spatial.StrategyTestCase;
 import org.apache.lucene.spatial.query.SpatialArgs;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/SpatialOpRecursivePrefixTreeTest.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/SpatialOpRecursivePrefixTreeTest.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/SpatialOpRecursivePrefixTreeTest.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/SpatialOpRecursivePrefixTreeTest.java	2020-06-09 01:52:52.274846825 +0000
@@ -18,14 +18,14 @@
  */
 
 import com.carrotsearch.randomizedtesting.annotations.Repeat;
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.context.SpatialContextFactory;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Rectangle;
-import com.spatial4j.core.shape.Shape;
-import com.spatial4j.core.shape.ShapeCollection;
-import com.spatial4j.core.shape.SpatialRelation;
-import com.spatial4j.core.shape.impl.RectangleImpl;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.context.SpatialContextFactory;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Shape;
+import org.locationtech.spatial4j.shape.ShapeCollection;
+import org.locationtech.spatial4j.shape.SpatialRelation;
+import org.locationtech.spatial4j.shape.impl.RectangleImpl;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.document.StoredField;
@@ -56,10 +56,10 @@
 import static com.carrotsearch.randomizedtesting.RandomizedTest.randomBoolean;
 import static com.carrotsearch.randomizedtesting.RandomizedTest.randomInt;
 import static com.carrotsearch.randomizedtesting.RandomizedTest.randomIntBetween;
-import static com.spatial4j.core.shape.SpatialRelation.CONTAINS;
-import static com.spatial4j.core.shape.SpatialRelation.DISJOINT;
-import static com.spatial4j.core.shape.SpatialRelation.INTERSECTS;
-import static com.spatial4j.core.shape.SpatialRelation.WITHIN;
+import static org.locationtech.spatial4j.shape.SpatialRelation.CONTAINS;
+import static org.locationtech.spatial4j.shape.SpatialRelation.DISJOINT;
+import static org.locationtech.spatial4j.shape.SpatialRelation.INTERSECTS;
+import static org.locationtech.spatial4j.shape.SpatialRelation.WITHIN;
 
 public class SpatialOpRecursivePrefixTreeTest extends StrategyTestCase {
 
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/TestRecursivePrefixTreeStrategy.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/TestRecursivePrefixTreeStrategy.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/TestRecursivePrefixTreeStrategy.java	2014-03-18 05:31:24.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/TestRecursivePrefixTreeStrategy.java	2020-06-09 01:52:52.270846766 +0000
@@ -17,10 +17,10 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.distance.DistanceUtils;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.distance.DistanceUtils;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.spatial.SpatialMatchConcern;
 import org.apache.lucene.spatial.StrategyTestCase;
 import org.apache.lucene.spatial.prefix.tree.GeohashPrefixTree;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/TestTermQueryPrefixGridStrategy.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/TestTermQueryPrefixGridStrategy.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/TestTermQueryPrefixGridStrategy.java	2014-01-24 20:16:49.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/TestTermQueryPrefixGridStrategy.java	2020-06-09 01:52:52.270846766 +0000
@@ -17,8 +17,8 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.document.StoredField;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/tree/SpatialPrefixTreeTest.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/tree/SpatialPrefixTreeTest.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/prefix/tree/SpatialPrefixTreeTest.java	2014-04-18 02:07:04.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/prefix/tree/SpatialPrefixTreeTest.java	2020-06-09 01:52:52.270846766 +0000
@@ -17,10 +17,10 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Rectangle;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.document.Field.Store;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/query/SpatialArgsParserTest.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/query/SpatialArgsParserTest.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/query/SpatialArgsParserTest.java	2014-07-08 20:18:47.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/query/SpatialArgsParserTest.java	2020-06-09 01:52:52.274846825 +0000
@@ -17,8 +17,8 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Rectangle;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Rectangle;
 import org.apache.lucene.util.LuceneTestCase;
 import org.junit.Test;
 
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/QueryEqualsHashCodeTest.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/QueryEqualsHashCodeTest.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/QueryEqualsHashCodeTest.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/QueryEqualsHashCodeTest.java	2020-06-09 01:52:52.266846707 +0000
@@ -17,8 +17,8 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Shape;
 //import org.apache.lucene.spatial.bbox.BBoxStrategy;
 import org.apache.lucene.spatial.bbox.BBoxStrategy;
 import org.apache.lucene.spatial.prefix.RecursivePrefixTreeStrategy;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/serialized/SerializedStrategyTest.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/serialized/SerializedStrategyTest.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/serialized/SerializedStrategyTest.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/serialized/SerializedStrategyTest.java	2020-06-09 01:52:52.274846825 +0000
@@ -17,7 +17,7 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
+import org.locationtech.spatial4j.context.SpatialContext;
 import org.apache.lucene.search.FilteredQuery;
 import org.apache.lucene.search.MatchAllDocsQuery;
 import org.apache.lucene.search.Query;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/SpatialArgsTest.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/SpatialArgsTest.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/SpatialArgsTest.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/SpatialArgsTest.java	2020-06-09 01:52:52.274846825 +0000
@@ -17,8 +17,8 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.spatial.query.SpatialArgs;
 import org.junit.Test;
 
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/SpatialExample.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/SpatialExample.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/SpatialExample.java	2014-01-24 20:16:49.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/SpatialExample.java	2020-06-09 01:52:52.278846884 +0000
@@ -17,10 +17,10 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.distance.DistanceUtils;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.distance.DistanceUtils;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.document.IntField;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/SpatialTestCase.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/SpatialTestCase.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/SpatialTestCase.java	2014-08-14 16:15:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/SpatialTestCase.java	2020-06-09 01:52:52.266846707 +0000
@@ -17,9 +17,9 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Rectangle;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Rectangle;
 import org.apache.lucene.analysis.MockAnalyzer;
 import org.apache.lucene.codecs.lucene410.Lucene410DocValuesFormat;
 import org.apache.lucene.document.Document;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/SpatialTestData.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/SpatialTestData.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/SpatialTestData.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/SpatialTestData.java	2020-06-09 01:52:52.274846825 +0000
@@ -17,8 +17,8 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Shape;
 
 import java.io.BufferedReader;
 import java.io.IOException;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/SpatialTestQuery.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/SpatialTestQuery.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/SpatialTestQuery.java	2014-03-31 20:43:48.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/SpatialTestQuery.java	2020-06-09 01:52:52.274846825 +0000
@@ -17,7 +17,7 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
+import org.locationtech.spatial4j.context.SpatialContext;
 
 import org.apache.lucene.spatial.query.SpatialArgs;
 import org.apache.lucene.spatial.query.SpatialArgsParser;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/StrategyTestCase.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/StrategyTestCase.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/StrategyTestCase.java	2014-07-08 20:11:47.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/StrategyTestCase.java	2020-06-09 01:52:52.266846707 +0000
@@ -18,8 +18,8 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.document.Document;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.document.StoredField;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/TestTestFramework.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/TestTestFramework.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/TestTestFramework.java	2014-03-12 18:14:05.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/TestTestFramework.java	2020-06-09 01:52:52.274846825 +0000
@@ -17,8 +17,8 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Rectangle;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Rectangle;
 import org.apache.lucene.spatial.query.SpatialArgsParser;
 import org.apache.lucene.spatial.query.SpatialOperation;
 import org.apache.lucene.util.LuceneTestCase;
diff -urN lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/vector/TestPointVectorStrategy.java lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/vector/TestPointVectorStrategy.java
--- lucene-4.10.4/spatial/src/test/org/apache/lucene/spatial/vector/TestPointVectorStrategy.java	2012-09-22 21:41:00.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/test/org/apache/lucene/spatial/vector/TestPointVectorStrategy.java	2020-06-09 01:52:52.266846707 +0000
@@ -17,9 +17,9 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Circle;
-import com.spatial4j.core.shape.Point;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Circle;
+import org.locationtech.spatial4j.shape.Point;
 import org.apache.lucene.search.Query;
 import org.apache.lucene.spatial.SpatialMatchConcern;
 import org.apache.lucene.spatial.StrategyTestCase;
diff -urN lucene-4.10.4/benchmark/src/java/org/apache/lucene/benchmark/byTask/feeds/SpatialFileQueryMaker.java lucene-4.10.4.new/benchmark/src/java/org/apache/lucene/benchmark/byTask/feeds/SpatialFileQueryMaker.java
--- lucene-4.10.4/benchmark/src/java/org/apache/lucene/benchmark/byTask/feeds/SpatialFileQueryMaker.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/benchmark/src/java/org/apache/lucene/benchmark/byTask/feeds/SpatialFileQueryMaker.java	2020-06-09 01:52:52.238846295 +0000
@@ -17,7 +17,7 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.benchmark.byTask.utils.Config;
 import org.apache.lucene.queries.CustomScoreQuery;
 import org.apache.lucene.queries.function.FunctionQuery;
@@ -36,7 +36,7 @@
 
 /**
  * Reads spatial data from the body field docs from an internally created {@link LineDocSource}.
  * It's parsed by {@link com.spatial4j.core.context.SpatialContext#readShapeFromWkt(String)} (String)} and then
  * further manipulated via a configurable {@link SpatialDocMaker.ShapeConverter}. When using point
  * data, it's likely you'll want to configure the shape converter so that the query shapes actually
  * cover a region. The queries are all created & cached in advance. This query maker works in
@@ -36,7 +36,7 @@
 /**
  * Reads spatial data from the body field docs from an internally created {@link LineDocSource}.
- * It's parsed by {@link com.spatial4j.core.context.SpatialContext#readShapeFromWkt(String)} (String)} and then
+ * It's parsed by {@link org.locationtech.spatial4j.context.SpatialContext#readShapeFromWkt(String)} (String)} and then
  * further manipulated via a configurable {@link SpatialDocMaker.ShapeConverter}. When using point
  * data, it's likely you'll want to configure the shape converter so that the query shapes actually
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/TermQueryPrefixTreeStrategy.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/TermQueryPrefixTreeStrategy.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/TermQueryPrefixTreeStrategy.java	2014-08-13 09:36:54.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/TermQueryPrefixTreeStrategy.java	2020-06-09 01:52:52.258846589 +0000
@@ -17,7 +17,7 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.shape.Shape;
 
 import org.apache.lucene.queries.TermsFilter;
 import org.apache.lucene.search.Filter;
@@ -32,7 +32,7 @@
 
 /**
  * A basic implementation of {@link PrefixTreeStrategy} using a large {@link
  * TermsFilter} of all the cells from {@link SpatialPrefixTree#getCells(com.spatial4j.core.shape.Shape,
  * int, boolean, boolean)}. It only supports the search of indexed Point shapes.
  * <p/>
  * The precision of query shapes (distErrPct) is an important factor in using
@@ -32,7 +32,7 @@
 /**
  * A basic implementation of {@link PrefixTreeStrategy} using a large {@link
- * TermsFilter} of all the cells from {@link SpatialPrefixTree#getCells(com.spatial4j.core.shape.Shape,
+ * TermsFilter} of all the cells from {@link SpatialPrefixTree#getCells(org.locationtech.spatial4j.shape.Shape,
  * int, boolean, boolean)}. It only supports the search of indexed Point shapes.
  * <p/>
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/tree/Cell.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/tree/Cell.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/tree/Cell.java	2014-04-18 02:07:04.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/tree/Cell.java	2020-06-09 01:52:52.250846472 +0000
@@ -17,9 +17,9 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Shape;
-import com.spatial4j.core.shape.SpatialRelation;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Shape;
+import org.locationtech.spatial4j.shape.SpatialRelation;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -149,8 +149,8 @@
 
   /**
    * Like {@link #getSubCells()} but with the results filtered by a shape. If
    * that shape is a {@link com.spatial4j.core.shape.Point} then it must call
    * {@link #getSubCell(com.spatial4j.core.shape.Point)}. The returned cells
    * should have {@link Cell#getShapeRel()} set to their relation with {@code
    * shapeFilter}. In addition, {@link Cell#isLeaf()}
    * must be true when that relation is WITHIN.
@@ -149,8 +149,8 @@
   /**
    * Like {@link #getSubCells()} but with the results filtered by a shape. If
-   * that shape is a {@link com.spatial4j.core.shape.Point} then it must call
-   * {@link #getSubCell(com.spatial4j.core.shape.Point)}. The returned cells
+   * that shape is a {@link org.locationtech.spatial4j.shape.Point} then it must call
+   * {@link #getSubCell(org.locationtech.spatial4j.shape.Point)}. The returned cells
    * should have {@link Cell#getShapeRel()} set to their relation with {@code
    * shapeFilter}. In addition, {@link Cell#isLeaf()}
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/tree/SpatialPrefixTree.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/tree/SpatialPrefixTree.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/tree/SpatialPrefixTree.java	2014-04-18 02:07:04.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/tree/SpatialPrefixTree.java	2020-06-09 01:52:52.254846531 +0000
@@ -17,10 +17,10 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Rectangle;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Shape;
 
 import java.nio.charset.Charset;
 import java.nio.charset.StandardCharsets;
@@ -145,7 +145,7 @@
    * leaf and none of its children are added.
    * <p/>
    * This implementation checks if shape is a Point and if so returns {@link
-   * #getCells(com.spatial4j.core.shape.Point, int, boolean)}.
+   * #getCells(org.locationtech.spatial4j.shape.Point, int, boolean)}.
    *
    * @param shape       the shape; non-null
    * @param detailLevel the maximum detail level to get cells for
@@ -213,7 +213,7 @@
 
   /**
    * A Point-optimized implementation of
    * {@link #getCells(com.spatial4j.core.shape.Shape, int, boolean, boolean)}. That
    * method in facts calls this for points.
    * <p/>
    * This implementation depends on {@link #getCell(String)} being fast, as its
@@ -213,7 +213,7 @@
   /**
    * A Point-optimized implementation of
-   * {@link #getCells(com.spatial4j.core.shape.Shape, int, boolean, boolean)}. That
+   * {@link #getCells(org.locationtech.spatial4j.shape.Shape, int, boolean, boolean)}. That
    * method in facts calls this for points.
    * <p/>
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/WithinPrefixTreeFilter.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/WithinPrefixTreeFilter.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/prefix/WithinPrefixTreeFilter.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/prefix/WithinPrefixTreeFilter.java	2020-06-09 01:52:52.254846531 +0000
@@ -17,13 +17,13 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.distance.DistanceUtils;
-import com.spatial4j.core.shape.Circle;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Rectangle;
-import com.spatial4j.core.shape.Shape;
-import com.spatial4j.core.shape.SpatialRelation;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.distance.DistanceUtils;
+import org.locationtech.spatial4j.shape.Circle;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Shape;
+import org.locationtech.spatial4j.shape.SpatialRelation;
 import org.apache.lucene.index.AtomicReaderContext;
 import org.apache.lucene.search.DocIdSet;
 import org.apache.lucene.spatial.prefix.tree.Cell;
@@ -57,7 +57,7 @@
   private final Shape bufferedQueryShape;//if null then the whole world
 
   /**
    * See {@link AbstractVisitingPrefixTreeFilter#AbstractVisitingPrefixTreeFilter(com.spatial4j.core.shape.Shape, String, org.apache.lucene.spatial.prefix.tree.SpatialPrefixTree, int, int)}.
    * {@code queryBuffer} is the (minimum) distance beyond the query shape edge
    * where non-matching documents are looked for so they can be excluded. If
    * -1 is used then the whole world is examined (a good default for correctness).
@@ -57,7 +57,7 @@
 
   /**
-   * See {@link AbstractVisitingPrefixTreeFilter#AbstractVisitingPrefixTreeFilter(com.spatial4j.core.shape.Shape, String, org.apache.lucene.spatial.prefix.tree.SpatialPrefixTree, int, int)}.
+   * See {@link AbstractVisitingPrefixTreeFilter#AbstractVisitingPrefixTreeFilter(org.locationtech.spatial4j.shape.Shape, String, org.apache.lucene.spatial.prefix.tree.SpatialPrefixTree, int, int)}.
    * {@code queryBuffer} is the (minimum) distance beyond the query shape edge
    * where non-matching documents are looked for so they can be excluded. If
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/query/SpatialArgsParser.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/query/SpatialArgsParser.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/query/SpatialArgsParser.java	2014-03-12 18:14:05.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/query/SpatialArgsParser.java	2020-06-09 01:52:52.258846589 +0000
@@ -17,9 +17,9 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.exception.InvalidShapeException;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.exception.InvalidShapeException;
+import org.locationtech.spatial4j.shape.Shape;
 
 import java.text.ParseException;
 import java.util.HashMap;
@@ -30,8 +30,8 @@
 /**
  * Parses a string that usually looks like "OPERATION(SHAPE)" into a {@link SpatialArgs}
  * object. The set of operations supported are defined in {@link SpatialOperation}, such
  * as "Intersects" being a common one. The shape portion is defined by WKT {@link com.spatial4j.core.io.WktShapeParser},
  * but it can be overridden/customized via {@link #parseShape(String, com.spatial4j.core.context.SpatialContext)}.
  * There are some optional name-value pair parameters that follow the closing parenthesis.  Example:
  * <pre>
  *   Intersects(ENVELOPE(-10,-8,22,20)) distErrPct=0.025
@@ -30,8 +30,8 @@
  * Parses a string that usually looks like "OPERATION(SHAPE)" into a {@link SpatialArgs}
  * object. The set of operations supported are defined in {@link SpatialOperation}, such
- * as "Intersects" being a common one. The shape portion is defined by WKT {@link com.spatial4j.core.io.WktShapeParser},
- * but it can be overridden/customized via {@link #parseShape(String, com.spatial4j.core.context.SpatialContext)}.
+ * as "Intersects" being a common one. The shape portion is defined by WKT {@link org.locationtech.spatial4j.io.WktShapeParser},
+ * but it can be overridden/customized via {@link #parseShape(String, org.locationtech.spatial4j.context.SpatialContext)}.
  * There are some optional name-value pair parameters that follow the closing parenthesis.  Example:
  * <pre>
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/query/SpatialOperation.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/query/SpatialOperation.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/query/SpatialOperation.java	2014-07-08 20:18:47.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/query/SpatialOperation.java	2020-06-09 01:52:52.258846589 +0000
@@ -17,9 +17,9 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.shape.Rectangle;
-import com.spatial4j.core.shape.Shape;
-import com.spatial4j.core.shape.SpatialRelation;
+import org.locationtech.spatial4j.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Shape;
+import org.locationtech.spatial4j.shape.SpatialRelation;
 
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -31,7 +31,7 @@
 /**
  * A predicate that compares a stored geometry to a supplied geometry. It's enum-like. For more
  * explanation of each predicate, consider looking at the source implementation
  * of {@link #evaluate(com.spatial4j.core.shape.Shape, com.spatial4j.core.shape.Shape)}. It's important
  * to be aware that Lucene-spatial makes no distinction of shape boundaries, unlike many standardized
  * definitions. Nor does it make dimensional distinctions (e.g. line vs polygon).
  * You can lookup a predicate by "Covers" or "Contains", for example, and you will get the
@@ -31,7 +31,7 @@
  * A predicate that compares a stored geometry to a supplied geometry. It's enum-like. For more
  * explanation of each predicate, consider looking at the source implementation
- * of {@link #evaluate(com.spatial4j.core.shape.Shape, com.spatial4j.core.shape.Shape)}. It's important
+ * of {@link #evaluate(org.locationtech.spatial4j.shape.Shape, org.locationtech.spatial4j.shape.Shape)}. It's important
  * to be aware that Lucene-spatial makes no distinction of shape boundaries, unlike many standardized
  * definitions. Nor does it make dimensional distinctions (e.g. line vs polygon).
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/serialized/SerializedDVStrategy.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/serialized/SerializedDVStrategy.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/serialized/SerializedDVStrategy.java	2014-08-14 09:15:35.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/serialized/SerializedDVStrategy.java	2020-06-09 01:52:52.258846589 +0000
@@ -17,10 +17,10 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.io.BinaryCodec;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.io.BinaryCodec;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.document.BinaryDocValuesField;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.index.AtomicReaderContext;
@@ -54,7 +54,7 @@
  * SpatialStrategy that is approximated (like {@link org.apache.lucene.spatial.prefix.RecursivePrefixTreeStrategy})
  * to add precision or eventually make more specific / advanced calculations on the per-document
  * geometry.
  * The serialization uses Spatial4j's {@link com.spatial4j.core.io.BinaryCodec}.
  *
  * @lucene.experimental
  */
@@ -54,7 +54,7 @@
  * to add precision or eventually make more specific / advanced calculations on the per-document
  * geometry.
- * The serialization uses Spatial4j's {@link com.spatial4j.core.io.BinaryCodec}.
+ * The serialization uses Spatial4j's {@link org.locationtech.spatial4j.io.BinaryCodec}.
  *
  * @lucene.experimental
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/SpatialStrategy.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/SpatialStrategy.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/SpatialStrategy.java	2013-07-24 17:25:11.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/SpatialStrategy.java	2020-06-09 01:52:52.262846648 +0000
@@ -17,10 +17,10 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Rectangle;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Rectangle;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.document.Field;
 import org.apache.lucene.queries.function.ValueSource;
 import org.apache.lucene.queries.function.valuesource.ReciprocalFloatFunction;
@@ -102,7 +102,7 @@
   public abstract Field[] createIndexableFields(Shape shape);
 
   /**
    * See {@link #makeDistanceValueSource(com.spatial4j.core.shape.Point, double)} called with
    * a multiplier of 1.0 (i.e. units of degrees).
    */
   public ValueSource makeDistanceValueSource(Point queryPoint) {
@@ -148,7 +148,7 @@
 
   /**
    * Returns a ValueSource with values ranging from 1 to 0, depending inversely
    * on the distance from {@link #makeDistanceValueSource(com.spatial4j.core.shape.Point,double)}.
    * The formula is {@code c/(d + c)} where 'd' is the distance and 'c' is
    * one tenth the distance to the farthest edge from the center. Thus the
    * scores will be 1 for indexed points at the center of the query shape and as
@@ -102,7 +102,7 @@
 
   /**
-   * See {@link #makeDistanceValueSource(com.spatial4j.core.shape.Point, double)} called with
+   * See {@link #makeDistanceValueSource(org.locationtech.spatial4j.shape.Point, double)} called with
    * a multiplier of 1.0 (i.e. units of degrees).
    */
@@ -148,7 +148,7 @@
   /**
    * Returns a ValueSource with values ranging from 1 to 0, depending inversely
-   * on the distance from {@link #makeDistanceValueSource(com.spatial4j.core.shape.Point,double)}.
+   * on the distance from {@link #makeDistanceValueSource(org.locationtech.spatial4j.shape.Point,double)}.
    * The formula is {@code c/(d + c)} where 'd' is the distance and 'c' is
    * one tenth the distance to the farthest edge from the center. Thus the
diff -urN lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/util/DistanceToShapeValueSource.java lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/util/DistanceToShapeValueSource.java
--- lucene-4.10.4/spatial/src/java/org/apache/lucene/spatial/util/DistanceToShapeValueSource.java	2014-08-07 05:21:33.000000000 +0000
+++ lucene-4.10.4.new/spatial/src/java/org/apache/lucene/spatial/util/DistanceToShapeValueSource.java	2020-06-09 01:52:52.262846648 +0000
@@ -17,10 +17,10 @@
  * limitations under the License.
  */
 
-import com.spatial4j.core.context.SpatialContext;
-import com.spatial4j.core.distance.DistanceCalculator;
-import com.spatial4j.core.shape.Point;
-import com.spatial4j.core.shape.Shape;
+import org.locationtech.spatial4j.context.SpatialContext;
+import org.locationtech.spatial4j.distance.DistanceCalculator;
+import org.locationtech.spatial4j.shape.Point;
+import org.locationtech.spatial4j.shape.Shape;
 import org.apache.lucene.index.AtomicReaderContext;
 import org.apache.lucene.queries.function.FunctionValues;
 import org.apache.lucene.queries.function.ValueSource;
@@ -34,7 +34,7 @@
 /**
  * The distance from a provided Point to a Point retrieved from a ValueSource via
  * {@link org.apache.lucene.queries.function.FunctionValues#objectVal(int)}. The distance
  * is calculated via a {@link com.spatial4j.core.distance.DistanceCalculator}.
  *
  * @lucene.experimental
  */
@@ -34,7 +34,7 @@
  * The distance from a provided Point to a Point retrieved from a ValueSource via
  * {@link org.apache.lucene.queries.function.FunctionValues#objectVal(int)}. The distance
- * is calculated via a {@link com.spatial4j.core.distance.DistanceCalculator}.
+ * is calculated via a {@link org.locationtech.spatial4j.distance.DistanceCalculator}.
  *
  * @lucene.experimental